<?php include_once 'codebase/hyperframe.php' ?><h1>The frame.php file</h1>

<h3>constructing a frame for your site</h3>

<p>The <em>frame.php</em> file must be present in each frame. It contains the HTML elements which are common to all webpages using this frame. In structure it is very like a typical webpage, and in fact it is possible to do the graphical design of a frame in any&nbsp; HTML editor (Dreamweaver, Kompozer, etc) and then add the hyperframe-specific frame components.</p>

<p>The first point to note is that only the &lt;head&gt; and &lt;body&gt; sections of frame.php are used by the Hyperframe system. <em>The rest is ignored</em>. Thus, there is absolutely no point in placing javascript or the like outside of the head or body, as it will never be seen by the browser.<br />
<br />
The frame head section contains items which determine the presentation of the page by Hyperframe, as well as the usual meta tags.</p>

<h4>A typical &lt;head&gt; section might contain:</h4>

<pre>
&lt;head&gt;
  &lt;title&gt;Hyperframe !CMS&lt;/title&gt;
  &lt;meta name=&quot;description&quot; content=&quot;HTML pages, content managed&quot;&gt;
  &lt;meta name=&quot;keywords&quot; content=&quot;content management, web frontend, html, pages&quot;&gt;
  &lt;META NAME=&quot;hf_doctype&quot; CONTENT=&quot;HTML&quot;&gt;
  &lt;META NAME=&quot;hf_hide&quot; CONTENT=&quot;&quot;&gt;
  &lt;meta name=&quot;Author&quot; content=&quot;IWR Consultancy&quot;&gt;
  &lt;meta http-equiv=&quot;Content-Type&quot; content=&quot;text/html; charset=utf-8&quot;&gt;
<span style="color:#D3D3D3;">  &lt;link rel=stylesheet href=&quot;&lt;?php echo codedir ?&gt;system.css&quot; type=&quot;text/css&quot;&gt;
  &lt;link rel=stylesheet href=&quot;&lt;?php echo framedir ?&gt;frame.css&quot; type=&quot;text/css&quot;&gt;
  &lt;script language=javascript src=&quot;&lt;?php echo codedir ?&gt;system.js&quot;&gt;&lt;/script&gt;
  &lt;script language=javascript src=&quot;&lt;?php echo framedir ?&gt;frame.js&quot;&gt;&lt;/script&gt;
</span>&nbsp; &lt;?php include_once plugin(&#39;menu&#39;); ?&gt;
&lt;/head&gt;</pre>

<p><em>The frame&#39;s head section in fact forms the definitive head section of all pages</em>, with the exception that certain items in the calling page&#39;s own head section may modify or over-ride those in the frame.</p>

<p>The <strong>title</strong> is used on all pages, and is prepended to any title found on an individual page. This conveniently avoids the need to keep repeating the site&#39;s name in titles. Where a page contains no title. the frame title is used, with the first &lt;Hn&gt; tag&#39;s contents appended. This in most cases will give rise to an acceptable title string which characterises the page&#39;s content.</p>

<p>The frame&#39;s <strong>description</strong> meta tag is only used if the calling page contains no <strong>title</strong>. If the page contains a title, its own description is used.</p>

<p>The <strong>author</strong> content -and any other unspecified meta content- applies to all pages, regardless.</p>

<h4>Several special hf_xxxx meta tags exist:</h4>

<p><strong>hf_doctype</strong> determines the &lt;!doctype&gt; declaration placed at the top of each rendered page. The possible values are:&nbsp;<br />
HTML (Default, HTML5)<br />
HTML5<br />
HTML4<br />
HTML4T<br />
HTML4F<br />
-which should be self-explanatory.<br />
To reiterate, any doctype declaration in the first line of the frame <em>will be ignored,</em> as will any in the calling page. The reason it&#39;s done like this, by the way, is that the online editor needs to know the document type, and it&#39;s simpler to use a variable of a known format than to scan the file for it. It also means that any extraneous doctype tags on imported pages will not affect operation.</p>

<p>The content-type meta tag behaves as usual in a static page, and should be as appropriate to the page character-set. Typically for HTML5 pages this will be utf-8, which allows for most international languages.</p>

<p><em>Hyperframe v3-on does not support XHTML</em>. This is not the problem it might seem for imported pages, since the majority of XHTML documents will display perfectly well as HTML5.</p>

<p>HTML4 support, which is mainly provided for easy import of legacy sites, includes switching the editor&#39;s semantics to generate the tags preferred by that standard. For example in HTML4 mode, the Bold&nbsp; button will insert a&nbsp; &lt;b&gt; tag, in HTML5 mode it will insert a &lt;strong&gt; tag.</p>

<p><strong>hf_hide</strong> takes any of the values <em>banner, top, left, content, right, bottom</em>&nbsp; comma separated, or the keyword <em>all</em>. It causes the relevant hf-[section] ID to <em>not</em> be displayed.&nbsp; hf_hide can be used in the frame, or in the calling page. This is useful where pages contain very wide content, and need more space.</p>

<p>The body section of frame.php constitutes the actual webpage as seen by the site visitor. This will typically consist of a collection of dividers separating content into a top banner, menus, actual page content, and various other embellishments. The page divisions may be created with div elements, HTML5 document section tags, or the more traditional approach of using a table. Purists would insist on the use of divs or HTML5 tags here, but in many instances it is far easier to achieve a consistent and reliable layout using a table than with the new mechanisms. Anyway, the choice is yours. Hyperframe itself doesn&#39;t care which you use.</p>

<p>The important point is that the Hyperframe system does expect to see a number of predefined css IDs in the body, which allow it to determine how to handle the content. What tags these IDs are attached to, is entirely up to you.</p>

<p>The structure here is that of a set of divs or&nbsp; tables defining these css IDs:<br />
<strong>ID: hf_banner</strong> - a top banner<br />
<strong>ID: hf_top</strong> - a topmenu line<br />
<strong>ID: hf_left</strong> - a lefthand bar<br />
<strong>ID: hf_content</strong>&nbsp; - the main content area<br />
<strong>ID: hf_right</strong> - a righthand bar (if used)<br />
<strong>ID: hf_bottom</strong> - a footer area.</p>

<h4>A div-based frame &lt;body&gt; section might contain:</h4>

<pre>
&lt;body&gt;
&lt;div class=&quot;hf_pagecontainer&quot;&gt;
  &lt;div id=&quot;hf_banner&quot; &gt;
    &lt;h1&gt;Hyperframe flatfile CMS&lt;/h1&gt;
  &lt;/div&gt;
  &lt;div id=&quot;hf_top&quot; &gt;
    &lt;div class=&quot;menutree topmenu&quot; &gt;
    &lt;a class=&quot;menu_single&quot; href=&quot;&lt;?php echo siteroot ?&gt;sitemap.php&quot;&gt;Site Map&lt;/a&gt;
    &lt;?php menu(&#39;tree.mnu&#39;,&#39;dropdown&#39;);?&gt;&lt;/div&gt;
    &lt;div style=&#39;text-align:right&#39;&gt;&lt;?php widgets();?&gt;&amp;nbsp;&lt;/div&gt;
  &lt;/div&gt;
  &lt;div id=&quot;midsection&quot;&gt;
    &lt;div id=&quot;hf_left&quot; &gt;
     &lt;img src=&quot;&lt;?php echo framedir ?&gt;sidelogo.gif&quot;&gt;
    &lt;/div&gt;
    &lt;div id=&quot;hf_content&quot; &gt;
      &lt;!--CONTENT--&gt;
    &lt;/div&gt;
  &lt;/div&gt;
  &lt;div id=&quot;hf_bottom&quot; &gt;
   Powered by Hyperframe &lt;br&gt;
  &lt;/div&gt;
  &amp;nbsp;  
&lt;/div&gt;
&lt;/body&gt;

</pre>

<h4>A table-based frame &lt;body&gt; section might contain:</h4>

<pre>
&lt;body&gt;
&lt;table class=&quot;hf_pagelayout&quot;&gt;
&lt;tr&gt;&lt;td id=&quot;hf_banner&quot; &gt;
  &lt;div float=&#39;left&#39; align=&#39;left&#39;&gt;&lt;img src=&#39;&lt;?php echo framedir ?&gt;hylogo.png&#39; align=&quot;left&quot;&gt;&lt;/div&gt;
  &lt;div float=&#39;right&#39; align=&#39;right&#39;&gt;&lt;span class=&#39;callout&#39;&gt;by IWR Consultancy&lt;/span&gt;&lt;/div&gt;
&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td id=&quot;hf_top&quot;&gt;
  &lt;div float=&#39;left&#39; align=&#39;left&#39;&gt;&lt;?php sitemenu(&#39;top&#39;);?&gt;&lt;/div&gt;
  &lt;div float=&#39;right&#39; align=&#39;right&#39;&gt;&lt;?php printbutton();?&gt;&amp;nbsp;&lt;/div&gt;
&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;

&lt;table class=&quot;hf_pagelayout&quot;&gt;&lt;tr&gt;
&lt;td id=&quot;hf_left&quot;&gt;
  &lt;?php sitemenu(&#39;side&#39;)?&gt;
  &lt;hr width=90%&gt;
&lt;/td&gt;
&lt;td id=&quot;hf_content&quot; &gt;
  &lt;!--CONTENT--&gt;
&lt;/td&gt;
&lt;td id=&quot;hf_right&quot;&gt;
  &amp;nbsp;
&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;

&lt;table class=&quot;hf_pagelayout&quot;&gt;
&lt;tr id=&quot;hf_bottom&quot;&gt;&lt;td &gt;
  &lt;p class=&#39;callout&#39;&gt;Powered by Hyperframe&lt;/p&gt;
&lt;td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;/body&gt;</pre>

<p>As we mentioned, whether you use divs or table cells to define these regions is entirely up to you. I prefer to use tables for fluid layouts because they always seem to give a more reliable placement of regions on various screen sizes. Divs are good for fixed-width styling. Because these css ID&#39;s are referred-to internally by Hyperframe, they should always be present in any frame <em>if</em> the relevant area exists. You can use these predetermined IDs for styling purposes, or you can add as many IDs or classes as you like of your own.&nbsp;&nbsp;</p>

<h4>&nbsp;</h4>

<h4>Images in the frame:</h4>

<p>A point to note is that images or media are loaded from the <em>calling page&#39;s</em> context, not the frame&#39;s context. Thus, images to be incorporated into the frame need to be either css backgrounds, or else need to be called with the special syntax : src=&#39;<strong>&lt;?php echo framedir ?&gt;</strong>filename&#39; -which will load the image from the frame directory regardless of what that is called-&nbsp; which is usually what is wanted.</p>

<p>The hf_content area contains a special tag, <strong>&lt;!--CONTENT--&gt;</strong> which must be <em>exactly</em> as shown. This is not a comment, but a placeholder for the individual page content within the frame. So far this is the only example of &#39;duck code&#39; within Hyperframe, and I&#39;d rather it were not there.. but this proved to be the simplest approach, so that&#39;s the way it is.</p>

<p>A frame has a subdirectory, <strong>menu_img</strong> which contains the small placeholder icons used in the lefthand cascading menu. Since it might be desirable to customise these for specific frames, it makes more sense for them to be bundled with the frame rather than with the menu itself.</p>

<h4>Menus:</h4>

<p>The first example displays a single dropdown menu with fixed content. The second example demonstrates the two-menu approach, in which the lefthand menu contains the full list of links, whereas the top-row menu shows only the most often-used links. In all cases where the menu system is used, the frame head must contain the line&nbsp; <strong>&lt;?php include_once plugin(&#39;menu&#39;); ?&gt;</strong> -otherwise the page will fail to load correctly.&nbsp; A menu is loaded by way of a php call to its function.</p>

<h4>Automation:</h4>

<p>The frame can contain any php or javascript code. A point to note if including php is that the execution order is system php code, php code in the calling page, <em>then</em> php code in the frame. Thus, values changed in the frame have no effect on those settings as far as the calling page is concerned. <em>This is probably the reverse of what you would intuitively expect, so take note. </em>Since javascript is executed by the browser after the page has been sent, this consideration does not apply there.</p>
